@@ -475,6 +475,9 @@ class ExperimentEngine:
             # For lightgbm models
             importances = model.feature_importance(importance_type="split")
             importance_type = "Split"
+        elif hasattr(model, "get_feature_importance"):
+            importances = model.get_feature_importance()
+            importance_type = "Feature importance"
         elif hasattr(model, "coef_"):
             # For linear models
             importances = np.abs(model.coef_.flatten())
