@@ -25,7 +25,7 @@ DB_PORT = (
 DB_NAME = (
     os.getenv("TEST_DB_NAME") if PYTHON_ENV == "Test" else os.getenv("DB_NAME", None)
 )
-DB_URI = (
+DB_URI: str = (
     os.getenv("TEST_DB_URI", None)
     if PYTHON_ENV == "Test"
     else os.getenv("DB_URI", None)
