@@ -49,7 +49,7 @@ class Experiment(Base):
         onupdate=func.now(),
         nullable=False,
     )
-    name = Column(String(50), nullable=False)
+    name = Column(String(255), nullable=False)
     path = Column(String(255))  # we do not have this at creation time
     type = Column(String(50), nullable=False)
     size = Column(Integer, nullable=False)
@@ -272,10 +272,13 @@ class Experiment(Base):
                 return None
 
             # Normalize scores (subtract min and divide by range)
+            # Guard against division by zero when only one observation or all equal
             min_rmse = min(rmse_scores)
-            range_rmse = max(rmse_scores) - min_rmse
+            max_rmse = max(rmse_scores)
+            range_rmse = max_rmse - min_rmse
             min_logloss = min(logloss_scores)
-            range_logloss = max(logloss_scores) - min_logloss
+            max_logloss = max(logloss_scores)
+            range_logloss = max_logloss - min_logloss
 
             # Calculate combined score for each experiment
             experiment_scores = []
@@ -283,9 +286,17 @@ class Experiment(Base):
                 if experiment.avg_rmse is None or experiment.avg_logloss is None:
                     continue
 
-                # Normalize both scores
-                norm_rmse = (experiment.avg_rmse - min_rmse) / range_rmse
-                norm_logloss = (experiment.avg_logloss - min_logloss) / range_logloss
+                # Normalize both scores (safe when range == 0)
+                norm_rmse = (
+                    0.0
+                    if range_rmse == 0
+                    else (experiment.avg_rmse - min_rmse) / range_rmse
+                )
+                norm_logloss = (
+                    0.0
+                    if range_logloss == 0
+                    else (experiment.avg_logloss - min_logloss) / range_logloss
+                )
 
                 # Calculate combined score (average of normalized scores)
                 combined_score = (norm_rmse + norm_logloss) / 2
