@@ -20,6 +20,7 @@ from sqlalchemy.dialects.mysql import insert
 
 from lecrapaud.db.session import get_db
 from lecrapaud.db.models.base import Base, with_db
+from lecrapaud.config import LECRAPAUD_TABLE_PREFIX
 
 
 class FeatureSelectionRank(Base):
@@ -41,10 +42,14 @@ class FeatureSelectionRank(Base):
     method = Column(String(50))
     training_time = Column(Integer)
     feature_id = Column(
-        BigInteger, ForeignKey("lecrapaud_features.id", ondelete="CASCADE")
+        BigInteger,
+        ForeignKey(f"{LECRAPAUD_TABLE_PREFIX}_features.id", ondelete="CASCADE"),
     )
     feature_selection_id = Column(
-        BigInteger, ForeignKey("lecrapaud_feature_selections.id", ondelete="CASCADE")
+        BigInteger,
+        ForeignKey(
+            f"{LECRAPAUD_TABLE_PREFIX}_feature_selections.id", ondelete="CASCADE"
+        ),
     )
 
     feature = relationship("Feature", lazy="selectin")
