@@ -19,6 +19,7 @@ from sqlalchemy.orm import relationship, Mapped, mapped_column, DeclarativeBase
 
 from lecrapaud.db.session import get_db
 from lecrapaud.db.models.base import Base
+from lecrapaud.config import LECRAPAUD_TABLE_PREFIX
 
 
 class ModelTraining(Base):
@@ -36,10 +37,12 @@ class ModelTraining(Base):
     best_params = Column(JSON)
     model_path = Column(String(255))
     training_time = Column(Integer)
-    model_id = Column(BigInteger, ForeignKey("lecrapaud_models.id"), nullable=False)
+    model_id = Column(
+        BigInteger, ForeignKey(f"{LECRAPAUD_TABLE_PREFIX}_models.id"), nullable=False
+    )
     model_selection_id = Column(
         BigInteger,
-        ForeignKey("lecrapaud_model_selections.id", ondelete="CASCADE"),
+        ForeignKey(f"{LECRAPAUD_TABLE_PREFIX}_model_selections.id", ondelete="CASCADE"),
         nullable=False,
     )
 
