@@ -629,6 +629,7 @@ class PreprocessFeature:
         """
 
         pcas_dict = {}
+        index_saved = df.index
 
         for pca_cross_sectional in self.pca_cross_sectional:
             name, index_col, columns_col, value_col = (
@@ -659,6 +660,7 @@ class PreprocessFeature:
             scores_df = pd.DataFrame(scores, index=pivot.index, columns=cols)
 
             df = df.merge(scores_df.reset_index(), on=index_col, how="left")
+            df.index = index_saved
             pcas_dict.update({name: pipe})
 
         return df, pcas_dict
