@@ -14,8 +14,6 @@ import pickle
 from pydantic import BaseModel
 import ast
 
-os.environ["COVERAGE_FILE"] = str(Path(".coverage").resolve())
-
 # ML models
 from sklearn.model_selection import TimeSeriesSplit
 from sklearn.calibration import CalibratedClassifierCV
@@ -80,6 +78,8 @@ from lecrapaud.db import (
     Experiment,
 )
 
+os.environ["COVERAGE_FILE"] = str(Path(".coverage").resolve())
+
 # Reproducible result
 keras.utils.set_random_seed(42)
 np.random.seed(42)
@@ -110,6 +110,63 @@ def test_hardware():
 warnings.filterwarnings("ignore", category=UserWarning, module="pydantic")
 
 
+class CatBoostWrapper:
+    """
+    Transparent proxy for a CatBoost model that accepts arbitrary keyword arguments
+    as direct attributes, while forwarding all method calls and properties.
+    """
+
+    __slots__ = ("_model", "_extra_attrs")
+
+    def __init__(self, model, **kwargs):
+        object.__setattr__(self, "_model", model)
+        object.__setattr__(self, "_extra_attrs", {})
+        # Register kwargs as direct attributes
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    # ---- Transparent access ----
+    def __getattr__(self, name):
+        """Forward attribute access to the underlying model if not found."""
+        model = object.__getattribute__(self, "_model")
+        if hasattr(model, name):
+            return getattr(model, name)
+        extra_attrs = object.__getattribute__(self, "_extra_attrs")
+        if name in extra_attrs:
+            return extra_attrs[name]
+        raise AttributeError(f"{type(self).__name__!r} has no attribute {name!r}")
+
+    def __setattr__(self, name, value):
+        """Set to wrapper or forward to model when appropriate."""
+        if name in CatBoostWrapper.__slots__:
+            object.__setattr__(self, name, value)
+            return
+
+        model = object.__getattribute__(self, "_model")
+        if hasattr(model, name):
+            setattr(model, name, value)
+        else:
+            extra_attrs = object.__getattribute__(self, "_extra_attrs")
+            extra_attrs[name] = value
+
+    def __dir__(self):
+        """Merge dir() from wrapper, model, and custom attributes."""
+        base = set(super().__dir__())
+        model_attrs = set(dir(object.__getattribute__(self, "_model")))
+        extra_attrs = set(object.__getattribute__(self, "_extra_attrs").keys())
+        return sorted(base | model_attrs | extra_attrs)
+
+    def __repr__(self):
+        model = object.__getattribute__(self, "_model")
+        extras = object.__getattribute__(self, "_extra_attrs")
+        return f"CatBoostWrapper(model={model.__class__.__name__}, extras={extras})"
+
+    @property
+    def model(self):
+        """Access the raw CatBoost model."""
+        return object.__getattribute__(self, "_model")
+
+
 class ModelEngine:
 
     def __init__(
@@ -157,8 +214,10 @@ class ModelEngine:
     def fit(self, *args):
         if self.recurrent:
             fit = self.fit_recurrent
-        elif (self.create_model == "lgb") or (self.create_model == "xgb"):
+        elif (self.model_name == "lgb") or (self.model_name == "xgb"):
             fit = self.fit_boosting
+        elif self.model_name == "catboost":
+            fit = self.fit_catboost
         else:
             fit = self.fit_sklearn
         model = fit(*args)
@@ -201,17 +260,113 @@ class ModelEngine:
 
         return model
 
+    def fit_catboost(self, x_train, y_train, x_val, y_val, params):
+        """
+        Train CatBoost models with native early stopping and log metrics to TensorBoard.
+        Also supports plotting of the primary eval metric if self.plot is True.
+        """
+        # Prepare constructor parameters
+        ctor_params = dict(params) if params else {}
+        early_stopping_rounds = ctor_params.pop("early_stopping_rounds", None)
+        # Alias support: num_boost_round -> iterations
+        num_boost_round = ctor_params.pop("num_boost_round", None)
+        if num_boost_round is not None and "iterations" not in ctor_params:
+            ctor_params["iterations"] = num_boost_round
+
+        # Determine classification/regression setup
+        labels = np.unique(y_train)
+        num_class = (
+            labels.size
+            if self.target_type == "classification" and labels.size > 2
+            else 1
+        )
+
+        if self.target_type == "regression":
+            ctor_params.setdefault("loss_function", "RMSE")
+            eval_metric = ctor_params.get("eval_metric", "RMSE")
+        else:
+            if num_class <= 2:
+                ctor_params.setdefault("loss_function", "Logloss")
+                eval_metric = ctor_params.get("eval_metric", "Logloss")
+            else:
+                ctor_params.setdefault("loss_function", "MultiClass")
+                eval_metric = ctor_params.get("eval_metric", "MultiClass")
+        ctor_params.setdefault("eval_metric", eval_metric)
+
+        # Instantiate CatBoost model from provided constructor
+        model = self.create_model(**ctor_params, allow_writing_files=False)
+
+        # Train with eval_set and early stopping
+        logger.info(f"Fitting the model {self.model_name}...")
+        logger.info(f"x_train shape: {x_train.shape}, x_val shape: {x_val.shape}")
+        logger.info(f"y_train shape: {y_train.shape}, y_val shape: {y_val.shape}")
+
+        model.fit(
+            x_train,
+            y_train,
+            eval_set=[(x_val, y_val)],
+            use_best_model=True,
+            early_stopping_rounds=early_stopping_rounds,
+            verbose=False,
+        )
+
+        # Retrieve evaluation results
+        evals_result = model.get_evals_result()
+        # CatBoost commonly uses 'learn' and 'validation' (or 'validation_0')
+        learn_key = "learn"
+        val_key = None
+        for k in evals_result.keys():
+            if k != learn_key:
+                val_key = k
+                break
+
+        # Ensure eval_metric exists; otherwise fallback to first available metric
+        if eval_metric not in evals_result.get(learn_key, {}):
+            if evals_result.get(learn_key):
+                eval_metric = next(iter(evals_result[learn_key].keys()))
+
+        # TensorBoard logging
+        writer = SummaryWriter(self.log_dir)
+        try:
+            # learn_scores = evals_result.get(learn_key, {}).get(eval_metric, [])
+            val_scores = (
+                evals_result.get(val_key, {}).get(eval_metric, []) if val_key else []
+            )
+            # for i, v in enumerate(learn_scores):
+            #     writer.add_scalar(f"CatBoost/train/{eval_metric}", v, i)
+            for i, v in enumerate(val_scores):
+                writer.add_scalar(f"CatBoost/{eval_metric}", v, i)
+        finally:
+            writer.close()
+
+        # Optional plotting of training progress
+        if self.plot and eval_metric and learn_key in evals_result and val_key:
+            logs = {
+                "train": evals_result[learn_key].get(eval_metric, []),
+                "val": evals_result[val_key].get(eval_metric, []),
+            }
+            plot_training_progress(
+                logs=logs,
+                model_name=self.model_name,
+                target_number=self.target_number,
+                title_suffix=f"Training Progress - {eval_metric}",
+            )
+
+        # Attach metadata for consistency with sklearn path
+        model_wrapped = CatBoostWrapper(
+            model, model_name=self.model_name, target_type=self.target_type
+        )
+        logger.info(
+            f"Successfully created a {model_wrapped.model_name} at {datetime.now()}"
+        )
+
+        self._model = model_wrapped
+        return model_wrapped
+
     def fit_boosting(self, x_train, y_train, x_val, y_val, params):
         """
         This is using lightGBM or XGboost C++ librairies
         """
-        lightGBM = self.create_model == "lgb"
-
-        # Experiments
-        boosting_dataset = lgb.Dataset if lightGBM else xgb.DMatrix
-        train_data = boosting_dataset(x_train, label=y_train)
-        val_data = boosting_dataset(x_val, label=y_val)
-
         # Create a TensorBoardX writer
         writer = SummaryWriter(self.log_dir)
         evals_result = {}
@@ -223,11 +378,13 @@ class ModelEngine:
             if self.target_type == "classification" and labels.size > 2
             else 1
         )
-        logger.info("Fitting the model...")
+        logger.info(f"Fitting the model {self.model_name}...")
         logger.info(f"x_train shape: {x_train.shape}, x_val shape: {x_val.shape}")
         logger.info(f"y_train shape: {y_train.shape}, y_val shape: {y_val.shape}")
 
-        if lightGBM:
+        if self.model_name == "lgb":
+            train_data = lgb.Dataset(x_train, label=y_train)
+            val_data = lgb.Dataset(x_val, label=y_val)
 
             def tensorboard_callback(env):
                 for i, metric in enumerate(env.evaluation_result_list):
@@ -252,18 +409,23 @@ class ModelEngine:
                     "objective": loss,
                     "metric": eval_metric,
                     "num_class": num_class,
+                    "verbose": -1,
                 },
                 num_boost_round=params["num_boost_round"],
                 train_set=train_data,
                 valid_sets=[train_data, val_data],
                 valid_names=["train", "val"],
                 callbacks=[
-                    lgb.early_stopping(stopping_rounds=params["early_stopping_rounds"]),
+                    lgb.early_stopping(
+                        stopping_rounds=params["early_stopping_rounds"], verbose=False
+                    ),
                     lgb.record_evaluation(evals_result),
                     tensorboard_callback,
                 ],
             )
         else:
+            train_data = xgb.DMatrix(x_train, label=y_train)
+            val_data = xgb.DMatrix(x_val, label=y_val)
 
             class TensorBoardCallback(xgb.callback.TrainingCallback):
 
@@ -300,6 +462,7 @@ class ModelEngine:
                 if self.target_type == "regression"
                 else ("logloss" if num_class <= 2 else "mlogloss")
             )
+            xgb.set_config(verbosity=0)
             model = xgb.train(
                 params={
                     **params["model_params"],
@@ -318,7 +481,7 @@ class ModelEngine:
                     tensorboard_callback,
                 ],
                 evals_result=evals_result,  # Record evaluation result
-                verbose_eval=0,
+                verbose_eval=10000,
             )
 
         model.model_name = self.create_model
@@ -1365,6 +1528,9 @@ def evaluate(
             average=("binary" if num_classes == 2 else "macro"),
         )
         score["ROC_AUC"] = float(roc_auc_score(y_true, y_pred_proba, multi_class="ovr"))
+        score["AVG_PRECISION"] = average_precision_score(
+            y_true, y_pred_proba, average="macro"
+        )
 
         # Store the complete thresholds dictionary
         if len(target_clf_thresholds.keys()) > 1:
