@@ -15,6 +15,7 @@ from sklearn.naive_bayes import GaussianNB
 # Ensemble models
 from lightgbm import LGBMRegressor, LGBMClassifier
 from xgboost import XGBRegressor, XGBClassifier
+from catboost import CatBoostRegressor, CatBoostClassifier
 from sklearn.ensemble import (
     RandomForestRegressor,
     AdaBoostRegressor,
@@ -464,6 +465,41 @@ ml_models = [
             },
         },
     },
+    {
+        "model_name": "catboost",
+        "recurrent": False,
+        "need_scaling": False,
+        "classification": {
+            "create_model": CatBoostClassifier,
+            "search_params": {
+                "iterations": tune.randint(50, 1000),
+                "num_boost_round": tune.randint(50, 1000),
+                "early_stopping_rounds": tune.randint(5, 50),
+                "learning_rate": tune.loguniform(1e-4, 0.5),
+                "depth": tune.randint(3, 10),
+                "l2_leaf_reg": tune.loguniform(1e-5, 10),
+                "bagging_temperature": tune.uniform(0.0, 1.0),
+                "rsm": tune.quniform(0.6, 1.0, 0.05),
+                "random_state": 42,
+                "verbose": False,
+            },
+        },
+        "regression": {
+            "create_model": CatBoostRegressor,
+            "search_params": {
+                "iterations": tune.randint(50, 1000),
+                "num_boost_round": tune.randint(50, 1000),
+                "early_stopping_rounds": tune.randint(5, 50),
+                "learning_rate": tune.loguniform(1e-4, 0.5),
+                "depth": tune.randint(3, 10),
+                "l2_leaf_reg": tune.loguniform(1e-5, 10),
+                "bagging_temperature": tune.uniform(0.0, 1.0),
+                "rsm": tune.quniform(0.6, 1.0, 0.05),
+                "random_state": 42,
+                "verbose": False,
+            },
+        },
+    },
 ]
 
 
